@@ -41,13 +41,15 @@ class AriaBot:
         self._populate_entity_handlers()
         self.session = None
         self.aria = None
+        self._delta_token = None
         if 'read_token_file' in self.env:
             self.read_token_file = pathlib.Path(self.env['read_token_file'])
             if not self.read_token_file.exists():
                 self.read_token_file.write_text('')
         else:
-            self.read_token_file = pathlib.Path(tempfile.NamedTemporaryFile('read_token_file.json'))
-            logging.warning('No read_token_file set in config, creating temp file {0}')
+            self.read_token_file = pathlib.Path('read_token_file.dat')
+            self.read_token_file.write_text('')
+            logging.warning('read_token_file not set in config, creating new file {0}'.format(self.read_token_file.name))
 
     @staticmethod
     def parse_environment(environment, config):
@@ -153,11 +155,10 @@ class AriaBot:
             raise AriaBotException('Missing required attribute from: '+str(CONFIG_REQUIRED))
 
         cer = None
-        delta_token = None
         try:
             cer = AriaService.read_cert(self.env['cert'])
-            delta_token = self.read_token_file.read_text()
-            logging.info('Resuming aria stream [{0}]'.format(delta_token))
+            self._delta_token = self.read_token_file.read_text()
+            logging.info('Resuming aria stream [{0}]'.format(self._delta_token))
         except AriaError as e:
             logging.error(e)
             sys.exit(1)
@@ -180,7 +181,7 @@ class AriaBot:
                     self.session = self.aria.who_am_i()
                     authenticated = True
 
-                for msg in self.aria.get_messages(delta_token=delta_token):
+                for msg in self.aria.get_messages(delta_token=self._delta_token):
                     # Check the cross-pod flag and ignore message if not valid.
                     # if (not cross_pod) and msg['header']['crossPod']:
                     #    logging.debug('Ignore cross-pod message from [{}]'.format(msg['from']))
@@ -229,7 +230,9 @@ class AriaBot:
                 elif status == 404:
                     # Datafeed not found - renewing
                     logging.warning(hte.response.text+' renewing datafeed')
+                    # Blank the delta token for the next read, causing a refresh
                     self.aria.delta_token = ''
+                    self._delta_token = ''
                 elif status == 502:
                     logging.error('Gateway error: {} retry in {} seconds'.format(hte.response.status_code, poll_retry))
                     sleep(poll_retry)
@@ -248,7 +251,10 @@ class AriaBot:
             except RequestException as reqE:
                 logging.error('Request Exception: {}'.format(reqE))
                 sleep(poll_retry)
-            self.read_token_file.write_text(self.aria.delta_token)
+            # if aria client has a token value from a new session, then write this to disk
+            if self.aria.delta_token != self._delta_token:
+                self._delta_token = self.aria.delta_token
+                self.read_token_file.write_text(self._delta_token)
 
 
 class AriaBotCommand:
